@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004 Damien Miller <djm@mindrot.org>
+ * Copyright (c) 2004,2005 Damien Miller <djm@mindrot.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -14,6 +14,8 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include "flowd-common.h"
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -24,10 +26,9 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "common.h"
 #include "addr.h"
 
-RCSID("$Id: addr.c,v 1.12 2005/03/11 19:07:48 djm Exp $");
+RCSID("$Id: addr.c,v 1.15 2005/10/13 11:27:44 djm Exp $");
 
 #define _SA(x)	((struct sockaddr *)(x))
 
