@@ -28,7 +28,7 @@
 #include <sys/types.h>
 #include "crc32.h"
 
-RCSID("$Id: crc32.c,v 1.5 2005/10/13 11:27:44 djm Exp $");
+RCSID("$Id: crc32.c,v 1.6 2006/10/21 04:34:08 djm Exp $");
 
 static const u_int32_t crc32tab[] = {
 	0x00000000L, 0x77073096L, 0xee0e612cL, 0x990951baL,
@@ -98,13 +98,13 @@ static const u_int32_t crc32tab[] = {
 };
 
 void
-crc32_start(u_int32_t *crcp)
+flowd_crc32_start(u_int32_t *crcp)
 {
 	*crcp = 0;
 }
 
 void
-crc32_update(const u_char *buf, u_int32_t size, u_int32_t *crcp)
+flowd_crc32_update(const u_char *buf, u_int32_t size, u_int32_t *crcp)
 {
 	u_int32_t i, crc;
 
@@ -115,12 +115,12 @@ crc32_update(const u_char *buf, u_int32_t size, u_int32_t *crcp)
 }
 
 u_int32_t
-crc32(const u_char *buf, u_int32_t size)
+flowd_crc32(const u_char *buf, u_int32_t size)
 {
 	u_int32_t crc;
 
-	crc32_start(&crc);
-	crc32_update(buf, size, &crc);
+	flowd_crc32_start(&crc);
+	flowd_crc32_update(buf, size, &crc);
 
 	return (crc);
 }
