@@ -41,7 +41,7 @@
 #include "atomicio.h"
 #include "peer.h"
 
-RCSID("$Id: flowd.c,v 1.74 2005/12/21 12:14:50 djm Exp $");
+RCSID("$Id: flowd.c,v 1.79 2008/07/24 23:55:02 djm Exp $");
 
 /* Dump unknown packet types */
 /* #define DEBUG_UNKNOWN */
@@ -354,7 +354,7 @@ process_flow(struct store_flow_complete *flow, struct flowd_config *conf,
 	    sizeof(fbuf), &flen, ebuf, sizeof(ebuf)) != STORE_ERR_OK)
 		logerrx("%s: exiting on %s", __func__, ebuf);
 
-	if (output_flow_enqueue(fbuf, flen,
+	if (log_fd != -1 && output_flow_enqueue(fbuf, flen,
 	    conf->opts & FLOWD_OPT_VERBOSE) == -1) {
 		output_flow_flush(log_fd, conf->opts & FLOWD_OPT_VERBOSE);
 		/* Must not fail after flush */
@@ -365,7 +365,8 @@ process_flow(struct store_flow_complete *flow, struct flowd_config *conf,
 
 	/* Track failures to send on log socket so we can reopen it */
 	if (log_socket != -1 && send(log_socket, fbuf, flen, 0) == -1) {
-		if ((logsock_num_errors % 10) == 0) {
+		if (logsock_num_errors > 0 &&
+		    (logsock_num_errors % 10) == 0) {
 			logit(LOG_WARNING, "log socket send: %s "
 			    "(num errors %d)", strerror(errno),
 			    logsock_num_errors);
@@ -712,8 +713,8 @@ nf9_rec_to_flow(struct peer_nf9_record *rec, struct store_flow_complete *flow,
 	V9_FIELD(NF9_OUTPUT_SNMP, IF_INDICES, ifndx.if_index_out);
 	V9_FIELD(NF9_SRC_AS, AS_INFO, asinf.src_as);
 	V9_FIELD(NF9_DST_AS, AS_INFO, asinf.dst_as);
-	V9_FIELD(NF9_LAST_SWITCHED, FLOW_TIMES, ftimes.flow_start);
-	V9_FIELD(NF9_FIRST_SWITCHED, FLOW_TIMES, ftimes.flow_finish);
+	V9_FIELD(NF9_LAST_SWITCHED, FLOW_TIMES, ftimes.flow_finish);
+	V9_FIELD(NF9_FIRST_SWITCHED, FLOW_TIMES, ftimes.flow_start);
 	V9_FIELD(NF9_IPV6_SRC_MASK, AS_INFO, asinf.src_mask);
 	V9_FIELD(NF9_IPV6_DST_MASK, AS_INFO, asinf.dst_mask);
 	V9_FIELD(NF9_ENGINE_TYPE, FLOW_ENGINE_INFO, finf.engine_type);
@@ -880,7 +881,7 @@ process_netflow_v9_template(u_int8_t *pkt, size_t len, struct peer_state *peer,
 			    (pkt + offset);
 			recs[i].type = ntohs(tmplr->type);
 			recs[i].len = ntohs(tmplr->length);
-			offset += sizeof(tmplr);
+			offset += sizeof(*tmplr);
 #ifdef DEBUG_NF9
 			logit(LOG_DEBUG, "  record %d: type %d len %d",
 			    i, recs[i].type, recs[i].len);
@@ -1184,7 +1185,7 @@ receive_many(struct flowd_config *conf, struct peers *peers, int net_fd)
 
 	for (i = 0; i < INPUT_MAX_PACKET_PER_FD; i++) {
 		if (receive_packet(conf, peers, net_fd) == 0) {
-			syslog(LOG_DEBUG, "Received max number of packets "
+			logit(LOG_DEBUG, "Received max number of packets "
 			    "(%d) on fd %d", INPUT_MAX_PACKET_PER_FD, net_fd);
 			return;
 		}
@@ -1364,7 +1365,7 @@ startup_listen_init(struct flowd_config *conf)
 	struct listen_addr *la;
 
 	TAILQ_FOREACH(la, &conf->listen_addrs, entry) {
-		if ((la->fd = open_listener(&la->addr, la->port,
+		if ((la->fd = open_listener(&la->addr, la->port, la->bufsiz,
 		    &conf->join_groups)) == -1) {
 			logerrx("Listener setup of [%s]:%d failed",
 			    addr_ntop_buf(&la->addr), la->port);
