@@ -1,4 +1,4 @@
-/*	$Id: privsep.h,v 1.8 2005/08/24 12:26:50 djm Exp $	*/
+/*	$Id: privsep.h,v 1.9 2007/10/24 01:04:11 djm Exp $	*/
 
 /*
  * Copyright (c) 2004,2005 Damien Miller <djm@mindrot.org>
@@ -27,7 +27,7 @@
 void privsep_init(struct flowd_config *, int *, const char *);
 int client_open_log(int);
 int client_open_socket(int);
-int open_listener(struct xaddr *, u_int16_t, struct join_groups *);
+int open_listener(struct xaddr *, u_int16_t, size_t, struct join_groups *);
 int read_config(const char *, struct flowd_config *);
 int client_reconfigure(int, struct flowd_config *);
 
